==> pgmarket-1.2.2.tar.gz: pgmarket-1.2.2/login.php <==
<?
/* login.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("application.inc.php");

/* form has been submitted, check if it the user login information is correct */
if (match_referer() && isset($HTTP_POST_VARS)) {
	$user = verify_login($HTTP_POST_VARS["username"], $HTTP_POST_VARS["password"]);

	if ($user) {
		$SESSION["user"] = $user;
		$SESSION["ip"] = $REMOTE_ADDR;

		if ($user["fiscalcode"] != "") {
			$SESSION["country"] = "it";
		} else {
			$SESSION["country"] = "";
		}

		/* if wantsurl is set, that means we came from a page that required
		 * log in, so let's go back there.  otherwise go back to the main page */
		$goto = empty($SESSION["wantsurl"]) ? $CFG->wwwroot : $SESSION["wantsurl"];
		header("Location: $goto");
		die;

	} else {
		$errormsg = $login_failed;
		$frm["username"] = $HTTP_POST_VARS["username"];
	}
} /* else if (!match_referer()) {
	if (get_referer() == "http://" . $HTTP_SERVER_VARS["HTTP_HOST"] . $CFG->wwwroot . "/users/signup.php") {
		$SESSION["wantsurl"] = $CFG->wwwroot;
	} else {
		$SESSION["wantsurl"] = get_full_referer();
	}
} */

include("$CFG->templatedir"."login_form.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function verify_login($username, $password) {
/* verify the username and password.  if it is a valid login, return an array
 * with the username, firstname, lastname, and email address of the user */

	$qid = db_query("
		SELECT username, usertype, firstname, lastname, fiscalcode, email, priv
		FROM users
		WHERE username = '$username' AND password = '$password'
	");

	$numr = db_num_rows($qid);
	if ( $numr > 0 ) {
		return db_fetch_array($qid, 0);
	} else {
		return false;
	}
}

?>

==> pgmarket-1.3.3.tar.gz: pgmarket-1.3.3/login.php <==
<?
/* login.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("application.inc.php");

/* form has been submitted, check if it the user login information is correct */
if (match_referer() && isset($HTTP_POST_VARS)) {
	$user = verify_login($HTTP_POST_VARS["username"], $HTTP_POST_VARS["password"]);

	if ($user) {
		$SESSION["user"] = $user;
		$SESSION["ip"] = $REMOTE_ADDR;

		if ($user["fiscalcode"] != "") {
			$SESSION["country"] = "it";
		} else {
			$SESSION["country"] = "";
		}

		/* if wantsurl is set, that means we came from a page that required
		 * log in, so let's go back there.  otherwise go back to the main page */
		$goto = empty($SESSION["wantsurl"]) ? $CFG->firstpage : $SESSION["wantsurl"];
		header("Location: $goto");
		die;

	} else {
		$errormsg = $login_failed;
		$frm["username"] = $HTTP_POST_VARS["username"];
	}
} /* else if (!match_referer()) {
	if (get_referer() == "http://" . $HTTP_SERVER_VARS["HTTP_HOST"] . $CFG->firstpage . "/users/signup.php") {
		$SESSION["wantsurl"] = $CFG->firstpage;
	} else {
		$SESSION["wantsurl"] = get_full_referer();
	}
} */

include("$CFG->templatedir"."login_form.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function verify_login($username, $password) {
/* verify the username and password.  if it is a valid login, return an array
 * with the username, firstname, lastname, and email address of the user */

	$qid = db_query("
		SELECT username, usertype, firstname, lastname, fiscalcode, email, priv
		FROM users
		WHERE username = '$username' AND password = '$password'
	");

	$numr = db_num_rows($qid);
	if ( $numr > 0 ) {
		return db_fetch_array($qid, 0);
	} else {
		return false;
	}
}

?>
